==> cdk8s-plus-20-1.0.0-beta.7-sources.jar: org/cdk8s/plus20/ServiceIngressV1BetaBackendOptions.java <==
package org.cdk8s.plus20;

/**
 * Options for setting up backends for ingress rules.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-24T22:49:58.433Z")
@software.amazon.jsii.Jsii(module = org.cdk8s.plus20.$Module.class, fqn = "cdk8s-plus-20.ServiceIngressV1BetaBackendOptions")
@software.amazon.jsii.Jsii.Proxy(ServiceIngressV1BetaBackendOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ServiceIngressV1BetaBackendOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The port to use to access the service.
     * <p>
     * <ul>
     * <li>This option will fail if the service does not expose any ports.</li>
     * <li>If the service exposes multiple ports, this option must be specified.</li>
     * <li>If the service exposes a single port, this option is optional and if
     * specified, it must be the same port exposed by the service.</li>
     * </ul>
     * <p>
     * Default: - if the service exposes a single port, this port will be used.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getPort() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ServiceIngressV1BetaBackendOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ServiceIngressV1BetaBackendOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ServiceIngressV1BetaBackendOptions> {
        private java.lang.Number port;

        /**
         * Sets the value of {@link ServiceIngressV1BetaBackendOptions#getPort}
         * @param port The port to use to access the service.
         *             <ul>
         *             <li>This option will fail if the service does not expose any ports.</li>
         *             <li>If the service exposes multiple ports, this option must be specified.</li>
         *             <li>If the service exposes a single port, this option is optional and if
         *             specified, it must be the same port exposed by the service.</li>
         *             </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder port(java.lang.Number port) {
            this.port = port;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ServiceIngressV1BetaBackendOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ServiceIngressV1BetaBackendOptions build() {
            return new Jsii$Proxy(port);
        }
    }

    /**
     * An implementation for {@link ServiceIngressV1BetaBackendOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ServiceIngressV1BetaBackendOptions {
        private final java.lang.Number port;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.port = software.amazon.jsii.Kernel.get(this, "port", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final java.lang.Number port) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.port = port;
        }

        @Override
        public final java.lang.Number getPort() {
            return this.port;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getPort() != null) {
                data.set("port", om.valueToTree(this.getPort()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("cdk8s-plus-20.ServiceIngressV1BetaBackendOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ServiceIngressV1BetaBackendOptions.Jsii$Proxy that = (ServiceIngressV1BetaBackendOptions.Jsii$Proxy) o;

            return this.port != null ? this.port.equals(that.port) : that.port == null;
        }

        @Override
        public final int hashCode() {
            int result = this.port != null ? this.port.hashCode() : 0;
            return result;
        }
    }
}

==> cdk8s-plus-20-2.0.0-beta.7-sources.jar: org/cdk8s/plus20/ServiceIngressV1BetaBackendOptions.java <==
package org.cdk8s.plus20;

/**
 * Options for setting up backends for ingress rules.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.59.0 (build eb02c92)", date = "2022-05-19T09:07:11.152Z")
@software.amazon.jsii.Jsii(module = org.cdk8s.plus20.$Module.class, fqn = "cdk8s-plus-20.ServiceIngressV1BetaBackendOptions")
@software.amazon.jsii.Jsii.Proxy(ServiceIngressV1BetaBackendOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ServiceIngressV1BetaBackendOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * The port to use to access the service.
     * <p>
     * <ul>
     * <li>This option will fail if the service does not expose any ports.</li>
     * <li>If the service exposes multiple ports, this option must be specified.</li>
     * <li>If the service exposes a single port, this option is optional and if
     * specified, it must be the same port exposed by the service.</li>
     * </ul>
     * <p>
     * Default: - if the service exposes a single port, this port will be used.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Number getPort() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ServiceIngressV1BetaBackendOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ServiceIngressV1BetaBackendOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ServiceIngressV1BetaBackendOptions> {
        java.lang.Number port;

        /**
         * Sets the value of {@link ServiceIngressV1BetaBackendOptions#getPort}
         * @param port The port to use to access the service.
         *             <ul>
         *             <li>This option will fail if the service does not expose any ports.</li>
         *             <li>If the service exposes multiple ports, this option must be specified.</li>
         *             <li>If the service exposes a single port, this option is optional and if
         *             specified, it must be the same port exposed by the service.</li>
         *             </ul>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder port(java.lang.Number port) {
            this.port = port;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ServiceIngressV1BetaBackendOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ServiceIngressV1BetaBackendOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ServiceIngressV1BetaBackendOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ServiceIngressV1BetaBackendOptions {
        private final java.lang.Number port;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.port = software.amazon.jsii.Kernel.get(this, "port", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.port = builder.port;
        }

        @Override
        public final java.lang.Number getPort() {
            return this.port;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getPort() != null) {
                data.set("port", om.valueToTree(this.getPort()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("cdk8s-plus-20.ServiceIngressV1BetaBackendOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ServiceIngressV1BetaBackendOptions.Jsii$Proxy that = (ServiceIngressV1BetaBackendOptions.Jsii$Proxy) o;

            return this.port != null ? this.port.equals(that.port) : that.port == null;
        }

        @Override
        public final int hashCode() {
            int result = this.port != null ? this.port.hashCode() : 0;
            return result;
        }
    }
}
